<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>AboutBox</name>
    <message>
        <location filename="../ui/aboutbox.ui" line="14"/>
        <source>About FMIT...</source>
        <translation>О FMIT...</translation>
    </message>
    <message>
        <location filename="../ui/aboutbox.ui" line="28"/>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <location filename="../ui/aboutbox.ui" line="88"/>
        <source>FMIT</source>
        <translation>FMIT</translation>
    </message>
    <message>
        <location filename="../ui/aboutbox.ui" line="98"/>
        <source>&lt;version&gt;</source>
        <translation>&lt;version&gt;</translation>
    </message>
    <message>
        <location filename="../ui/aboutbox.ui" line="123"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Ubuntu&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Ubuntu&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/aboutbox.ui" line="143"/>
        <source>Credits</source>
        <translation>Список участников</translation>
    </message>
    <message>
        <location filename="../ui/aboutbox.ui" line="158"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Ubuntu&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Most open-source softwares are infeasible without indirect contributions provided through libraries. Thus, big thanks to the following geeks:&lt;br /&gt;&lt;br /&gt;- dsboger for so many little and usefull changes, updates, packaging, etc.&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Florian Hars for the tunning scales&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Arnout Engelen for the JACK issues&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- John Anderson for the microtonal module idea&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Scott Bahling for the scales in cents&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Jacob Shapiro for his help to make FMIT working under Windows/Cygwin.&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;- Translators: Omega9 (Russian), skarmoutsosv (Greek), Pindaro and dsboger (Portuguese and Brazilian Portuguese), Florian Maier (German).&lt;br /&gt;&lt;br /&gt;- &lt;a href=&quot;http://www.fftw.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;FFTW3&lt;/span&gt;&lt;/a&gt;&apos; for the very Fast Fourier Transform.&lt;br /&gt;&lt;br /&gt;- &lt;a href=&quot;http://www.qt.io/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Qt&lt;/span&gt;&lt;/a&gt;&apos;s team for the GUI library.&lt;br /&gt;&lt;br /&gt;Any contribution of any sort is very welcome!&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Ubuntu&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Большинство программ с открытым исходным кодом не существовало бы без косвенных взносов сообщества в библиотеки, лежащие в их основе. Так что скажем огромное спасибо следующим гикам:&lt;br /&gt;&lt;br /&gt;— dsboger’у за множество мелких и полезных изменений, обновлений, создание пакета и прочие вещи.&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;— Флориану Харсу за строи&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;— Арно Энгелену за замечания по JACK&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;— Джону Андерсону за идею микротонального модуля&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;— Скотту Бахлингу за строи в центах&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;— Якобу Шапиро за его помощь в налаживании работы FMIT в Windows/Cygwin.&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;— Переводчикам: Omega9 (на русский), skarmoutsosv (на греческий), Pindaro и dsboger (на португальский и бразильский португальский), Флориану Майеру (на немецкий).&lt;br /&gt;&lt;br /&gt;— &lt;a href=&quot;http://www.fftw.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;FFTW3&lt;/span&gt;&lt;/a&gt; за очень быстрое преобразование Фурье.&lt;br /&gt;&lt;br /&gt;— команде &lt;a href=&quot;http://www.qt.io/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Qt&lt;/span&gt;&lt;/a&gt; за библиотеку для графического пользовательского интерфейса.&lt;br /&gt;&lt;br /&gt;Любой вклад любого рода очень приветствуется!&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigForm</name>
    <message>
        <location filename="../ui/ConfigForm.ui" line="14"/>
        <source>Configuration</source>
        <translation>Настройка</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="46"/>
        <source>General</source>
        <translation>Основные</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="60"/>
        <source>Start in full-screen</source>
        <translation>Запускать в полноэкранном режиме</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="82"/>
        <source>Tuning scale</source>
        <translation>Строй</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="96"/>
        <source>Chromatic</source>
        <translation>Хроматический</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="101"/>
        <source>Werckmeister III</source>
        <translation>Werckmeister III</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="106"/>
        <source>Kirnberger III</source>
        <translation>Kirnberger III</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="111"/>
        <source>Diatonic</source>
        <translation>Диатонический</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="116"/>
        <source>Meantone (1/4)</source>
        <translation>Среднетоновый (1/4)</translation>
    </message>
    <message>
        <source>Tonality</source>
        <translation type="vanished">Тональность</translation>
    </message>
    <message>
        <source>C (Do)</source>
        <translation type="vanished">C (До)</translation>
    </message>
    <message>
        <source>Bb (Sib)</source>
        <translation type="vanished">Bb (Си-бемоль)</translation>
    </message>
    <message>
        <source>Eb (Mib)</source>
        <translation type="vanished">Eb (Ми-бемоль)</translation>
    </message>
    <message>
        <source>Use anglo-saxon or latin note names:
anglo-saxon: C D E F G A B
latin: Do Re Mi Fa Sol La Si</source>
        <translation type="vanished">Использовать англо-саксонские или латинские названия нот:
англо-саксонские: C D E F G A B
латинские: До Ре Ми Фа Соль Ля Си</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="170"/>
        <source>Note names</source>
        <translation>Названия нот</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="188"/>
        <source>Anglo-Saxon</source>
        <translation>Англо-саксонские</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="193"/>
        <source>Latin</source>
        <translation>Латинские</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="266"/>
        <source>Capture System</source>
        <translation>Способ захвата звука</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="307"/>
        <source>Auto-detect an available capture system at startup</source>
        <translation>Определять доступный способ захвата звука при запуске</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="323"/>
        <source>Auto detect now</source>
        <translation>Определить сейчас</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="332"/>
        <source>JACK</source>
        <translation>JACK</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="346"/>
        <source>Client name</source>
        <translation>Название клиента</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="368"/>
        <source>fmit</source>
        <translation>fmit</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="415"/>
        <location filename="../ui/ConfigForm.ui" line="418"/>
        <location filename="../ui/ConfigForm.ui" line="428"/>
        <location filename="../ui/ConfigForm.ui" line="431"/>
        <source>Sampling rate of the JACK server</source>
        <translation>Частота дискретизации сервера JACK</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="495"/>
        <location filename="../ui/ConfigForm.ui" line="611"/>
        <location filename="../ui/ConfigForm.ui" line="723"/>
        <location filename="../ui/ConfigForm.ui" line="835"/>
        <source>Sampling rate</source>
        <translation>Частота дискретизации</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="443"/>
        <source>ALSA</source>
        <translation>ALSA</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="160"/>
        <location filename="../ui/ConfigForm.ui" line="165"/>
        <location filename="../ui/ConfigForm.ui" line="177"/>
        <location filename="../ui/ConfigForm.ui" line="182"/>
        <source>Use localized note names. e.g.:
anglo-saxon: C D E F G A B
latin: Do Re Mi Fa Sol La Si</source>
        <translation>Использовать локализованные имена нот. Например:
англо-саксонские: C D E F G A B
латинские: Do Re Mi Fa Sol La Si</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="457"/>
        <location filename="../ui/ConfigForm.ui" line="573"/>
        <location filename="../ui/ConfigForm.ui" line="689"/>
        <location filename="../ui/ConfigForm.ui" line="801"/>
        <source>Device name</source>
        <translation>Название устройства</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="542"/>
        <location filename="../ui/ConfigForm.ui" line="658"/>
        <location filename="../ui/ConfigForm.ui" line="770"/>
        <location filename="../ui/ConfigForm.ui" line="882"/>
        <source>Do not use a too big sampling rate. 22050Hz should be largely enough in most cases.</source>
        <translation>Не назначайте слишком высокую частоту дискретизации. 22050 Гц достаточно в большинстве случаев.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="559"/>
        <source>OSS</source>
        <translation>OSS</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="567"/>
        <location filename="../ui/ConfigForm.ui" line="570"/>
        <location filename="../ui/ConfigForm.ui" line="586"/>
        <location filename="../ui/ConfigForm.ui" line="589"/>
        <source>The name of the OSS device to connect to</source>
        <translation>Название устройства OSS</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="592"/>
        <source>/dev/dsp</source>
        <translation>/dev/dsp</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="675"/>
        <source>PortAudio</source>
        <translation>PortAudio</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="683"/>
        <location filename="../ui/ConfigForm.ui" line="686"/>
        <location filename="../ui/ConfigForm.ui" line="696"/>
        <location filename="../ui/ConfigForm.ui" line="699"/>
        <location filename="../ui/ConfigForm.ui" line="795"/>
        <location filename="../ui/ConfigForm.ui" line="798"/>
        <location filename="../ui/ConfigForm.ui" line="808"/>
        <location filename="../ui/ConfigForm.ui" line="811"/>
        <source>The name of the PortAudio device to connect to</source>
        <translation>Название устройства PortAudio</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="476"/>
        <location filename="../ui/ConfigForm.ui" line="703"/>
        <location filename="../ui/ConfigForm.ui" line="815"/>
        <source>default</source>
        <translation>default</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="52"/>
        <location filename="../ui/ConfigForm.ui" line="56"/>
        <source>Raise the window to the whole screen when the program is started
(You can also use the shortcut &apos;f&apos;).</source>
        <translation>Запускать распахнутым на весь экран (клавиша &quot;f&quot;).</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="67"/>
        <source>Auto-save configuration and layout on exit</source>
        <translation>Запоминать настройки и положение окна по завершению</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="76"/>
        <location filename="../ui/ConfigForm.ui" line="79"/>
        <location filename="../ui/ConfigForm.ui" line="89"/>
        <location filename="../ui/ConfigForm.ui" line="92"/>
        <source>The used tuning scale to determine note frequency values. Useful for tuning historic intruments.</source>
        <translation>Используемый строй для определения частоты ноты. Полезно для настройки исторических инструментов.</translation>
    </message>
    <message>
        <source>The used tonality.
Useful to convert note names to a corresponding instrument tonality (e.g. Eb for saxophone, Bb for trumpet).</source>
        <translation>Используемая тональность.
Полезно при изменении имен нот в соответствии с тональностью инструмента (напр. Eb для саксофона, Bb для трубы).</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="198"/>
        <source>German</source>
        <translation>Немецкий</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="203"/>
        <source>Hindustani</source>
        <translation>Индийский</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="208"/>
        <source>Byzantine</source>
        <translation>Византийский</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="274"/>
        <location filename="../ui/ConfigForm.ui" line="277"/>
        <source>The capture system (e.g. JACK, ALSA, OSS, PortAudio)</source>
        <translation>Способ захвата звука (JACK, ALSA, OSS, PortAudio)</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="280"/>
        <source>The capture system</source>
        <translation>Способ захвата звука</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="287"/>
        <location filename="../ui/ConfigForm.ui" line="290"/>
        <source>Selected the capture system (e.g. JACK, ALSA, OSS, PortAudio)</source>
        <translation>Выбранный способ захвата звука (JACK, ALSA, OSS, PortAudio)</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="301"/>
        <location filename="../ui/ConfigForm.ui" line="304"/>
        <location filename="../ui/ConfigForm.ui" line="317"/>
        <location filename="../ui/ConfigForm.ui" line="320"/>
        <source>Auto detect a working capture system at FMIT startup.</source>
        <translation>Определять рабочий способ захвата звука при запуске FMIT.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="340"/>
        <location filename="../ui/ConfigForm.ui" line="343"/>
        <location filename="../ui/ConfigForm.ui" line="362"/>
        <location filename="../ui/ConfigForm.ui" line="365"/>
        <source>The name of this FMIT instance in the JACK connections.</source>
        <translation>Название соединения FMIT в JACK.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="379"/>
        <location filename="../ui/ConfigForm.ui" line="382"/>
        <location filename="../ui/ConfigForm.ui" line="401"/>
        <location filename="../ui/ConfigForm.ui" line="404"/>
        <source>Automatically connect FMIT to the following source at startup (e.g. alsa_pcm:capture_1)</source>
        <translation>Автоматически соединять FMIT со следующими источниками при запуске (напр. alsa_pcm:capture_1)</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="385"/>
        <source>automaticaly connect to...</source>
        <translation>автоматически соединять с...</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="421"/>
        <source>JACK sampling rate</source>
        <translation>Частота дискретизации JACK</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="451"/>
        <location filename="../ui/ConfigForm.ui" line="454"/>
        <location filename="../ui/ConfigForm.ui" line="470"/>
        <location filename="../ui/ConfigForm.ui" line="473"/>
        <source>The name of the ALSA device to use.</source>
        <translation>Название устройства ALSA.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="487"/>
        <location filename="../ui/ConfigForm.ui" line="491"/>
        <location filename="../ui/ConfigForm.ui" line="504"/>
        <location filename="../ui/ConfigForm.ui" line="508"/>
        <location filename="../ui/ConfigForm.ui" line="603"/>
        <location filename="../ui/ConfigForm.ui" line="607"/>
        <location filename="../ui/ConfigForm.ui" line="620"/>
        <location filename="../ui/ConfigForm.ui" line="624"/>
        <location filename="../ui/ConfigForm.ui" line="715"/>
        <location filename="../ui/ConfigForm.ui" line="719"/>
        <location filename="../ui/ConfigForm.ui" line="732"/>
        <location filename="../ui/ConfigForm.ui" line="736"/>
        <location filename="../ui/ConfigForm.ui" line="827"/>
        <location filename="../ui/ConfigForm.ui" line="831"/>
        <location filename="../ui/ConfigForm.ui" line="844"/>
        <location filename="../ui/ConfigForm.ui" line="848"/>
        <source>The chosen sampling rate.
Do not use a too big sampling rate. 22050Hz should be enough in most cases.</source>
        <translation>Назначенная частота дискретизации.
Не назначайте слишком высокую частоту дискретизации. 22050 Гц достаточно в большинстве случаев.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="525"/>
        <location filename="../ui/ConfigForm.ui" line="528"/>
        <location filename="../ui/ConfigForm.ui" line="641"/>
        <location filename="../ui/ConfigForm.ui" line="644"/>
        <location filename="../ui/ConfigForm.ui" line="753"/>
        <location filename="../ui/ConfigForm.ui" line="756"/>
        <location filename="../ui/ConfigForm.ui" line="865"/>
        <location filename="../ui/ConfigForm.ui" line="868"/>
        <source>Set the sampling rate to the maximum possible value.</source>
        <translation>Установите частоту дискретизации на максимальное возможное значение.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="531"/>
        <location filename="../ui/ConfigForm.ui" line="647"/>
        <location filename="../ui/ConfigForm.ui" line="759"/>
        <location filename="../ui/ConfigForm.ui" line="871"/>
        <source>set to max</source>
        <translation>установить на макс</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="549"/>
        <location filename="../ui/ConfigForm.ui" line="665"/>
        <location filename="../ui/ConfigForm.ui" line="777"/>
        <location filename="../ui/ConfigForm.ui" line="889"/>
        <source>Mix channels if there are multiple (if unchecked, the first channel will be used)</source>
        <translation>Смешивать звук при наличии нескольких каналов (если отключено, будет использован первый по счету канал)</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="787"/>
        <source>Qt</source>
        <translation>Qt</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="916"/>
        <source>Sound Analysis</source>
        <translation>Анализ звука</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="924"/>
        <location filename="../ui/ConfigForm.ui" line="928"/>
        <location filename="../ui/ConfigForm.ui" line="939"/>
        <location filename="../ui/ConfigForm.ui" line="943"/>
        <source>Time between each sound analysis.
Can be increased to get less CPU usage (but less temporal precision).</source>
        <translation>Время между каждым анализом звука.
Может быть увеличено для снижения нагрузки на процессор (но точность анализа снизится).</translation>
    </message>
    <message>
        <source>Range of possible notes from the lowest to the highest around the A4 reference note.
Smaller the range, smaller the CPU usage.</source>
        <translation type="vanished">Диапазон возможных нот от самой низкой до самой высокой вокруг базовой ноты A4. Чем меньше диапазон, тем меньше нагрузка на процессор.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="967"/>
        <source>Notes range</source>
        <translation>Диапазон нот</translation>
    </message>
    <message>
        <source>Lowest semitone from the A4 reference note.
It can useful to put it higher than -35 to avoid disturbance from the sector alimentation (~50hz).</source>
        <translation type="vanished">Самый низкий полутон от базовой ноты A4.
Может быть полезнее поставить его выше, чем -35, чтобы избежать нарушения от алиментации сектора (~50 Гц).</translation>
    </message>
    <message>
        <source>Highest semitone from the A4 reference note.</source>
        <translation type="vanished">Самый высокий полутон от базовой ноты A4.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1018"/>
        <location filename="../ui/ConfigForm.ui" line="1021"/>
        <source>Filter the sound below the lowest semitone and above the highest semitone to avoid artefacts and noises in all the following steps of the sound analysis.</source>
        <translation>Отфильтровывать звук ниже самого низкого полутона и выше самого высокого полутона, чтобы избежать артефактов и шума во всех следующих шагах анализа звука.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1024"/>
        <source>Notes range filtering</source>
        <translation>Фильтрация диапазона нот</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1070"/>
        <location filename="../ui/ConfigForm.ui" line="1074"/>
        <location filename="../ui/ConfigForm.ui" line="1100"/>
        <location filename="../ui/ConfigForm.ui" line="1104"/>
        <location filename="../ui/ConfigForm.ui" line="1278"/>
        <location filename="../ui/ConfigForm.ui" line="1282"/>
        <source>Ignore all sounds with volume below this threshold [dB]
(Shown as a red line in various views)</source>
        <translation>Игнорировать звук ниже указанного порога [дБ]
(Порог отмечен красной линией в разных режимах отображения)</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1131"/>
        <location filename="../ui/ConfigForm.ui" line="1136"/>
        <location filename="../ui/ConfigForm.ui" line="1163"/>
        <location filename="../ui/ConfigForm.ui" line="1168"/>
        <location filename="../ui/ConfigForm.ui" line="1188"/>
        <location filename="../ui/ConfigForm.ui" line="1193"/>
        <source>Ignore weak sub-harmonics.
This threshold is defined between two neighbors frequency components.
Prevents underestimation errors.</source>
        <translation>Игнорировать слабые субгармоники.
Этот порог определяется между двумя соседними составляющими частоты.
Предотвращает ошибки недооценки.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1207"/>
        <location filename="../ui/ConfigForm.ui" line="1211"/>
        <location filename="../ui/ConfigForm.ui" line="1240"/>
        <location filename="../ui/ConfigForm.ui" line="1244"/>
        <location filename="../ui/ConfigForm.ui" line="1263"/>
        <location filename="../ui/ConfigForm.ui" line="1267"/>
        <source>Factor defining the window size (from the lowest possible period defined by the notes range).
The bigger this factor, the more stable the analysis. However, by increasing this factor, FMIT will need more CPU and will react slower to sound changes.</source>
        <translation>Коэффициент, определяющий размер окна (от самого низкого возможного периода, определенного диапазоном нот).
Чем больше этот коэффициент, тем более стабилен анализ. Но при его увеличении, возрастёт нагрузка на процессор, а реакция на изменения звука будет медленнее.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1472"/>
        <location filename="../ui/ConfigForm.ui" line="1476"/>
        <location filename="../ui/ConfigForm.ui" line="1487"/>
        <location filename="../ui/ConfigForm.ui" line="1491"/>
        <source>Quantize the analysis results: ignore frequency jumps, fill gaps, ignore short notes.
The smaller the value, the faster the tuner. However, by decreasing the value, the computed frequency will be more unstable.</source>
        <translation>Квантование результатов анализа: игнорировать скачки частоты, заполнить пробелы, игнорировать короткие ноты.
Чем меньше значение, тем быстрее тюнер. Но при уменьшении значения, определение частот станет менее стабильным.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1538"/>
        <location filename="../ui/ConfigForm.ui" line="1541"/>
        <source>Restore settings as if you just installed FMIT (requires to restart FMIT).</source>
        <translation>Восстановить настройки так, будто вы только установили FMIT (требуется перезапуск FMIT).</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1567"/>
        <location filename="../ui/ConfigForm.ui" line="1570"/>
        <source>Use these settings and quit the configuration panel (it is required to click on the &quot;Save settings&quot; button to permanently keep these settings for each FMIT start)</source>
        <translation type="unfinished">Использовать эти настройки и покинуть окно настройки (требуется нажать на кнопку &quot;Сохранить настройки&quot;, чтобы сохранить эти настройки для каждого запуска FMIT)</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1586"/>
        <location filename="../ui/ConfigForm.ui" line="1589"/>
        <source>Discard any changes and quit the configuration panel</source>
        <translation>Отменить все изменения и покинуть окно настройки</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="932"/>
        <source>Refresh time</source>
        <translation>Время обновления</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="128"/>
        <source>Transposition</source>
        <translation>Транспонирование</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="238"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body&gt;
&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;To get more options, right-click every view to show up their properties!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body&gt;
&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Для получения дополнительных настроек представлений и просмотра их свойств, нажмите на нём правой кнопкой мыши!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="947"/>
        <location filename="../ui/ConfigForm.ui" line="1495"/>
        <source> ms</source>
        <translation> мс</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1033"/>
        <source>Rectangular filter: bad precision, but very fast</source>
        <translation>Прямоугольный фильтр: низкая точность, но очень высокая скорость обработки</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1046"/>
        <source>FIR filter: good precision, but more costly in CPU usage</source>
        <translation>FIR-фильтр: высокая точность, но большая нагрузка на процессор</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1056"/>
        <location filename="../ui/ConfigForm.ui" line="1059"/>
        <source>Algorithm settings</source>
        <translation>Настроить алгоритм</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1062"/>
        <source>Algorithm</source>
        <translation>Алгоритм</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1108"/>
        <location filename="../ui/ConfigForm.ui" line="1173"/>
        <source> dB</source>
        <translation> дБ</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1198"/>
        <source>Use sub-harmonic audibility threshold</source>
        <translation>Использовать субгармонический порог слышимости</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1271"/>
        <source>Window size factor</source>
        <translation>Коэффициент размера фрейма</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1286"/>
        <source>Volume threshold</source>
        <translation>Порог громкости</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1296"/>
        <location filename="../ui/ConfigForm.ui" line="1299"/>
        <source>Frequency refinement settings</source>
        <translation>Настройка частоты уточнения</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1302"/>
        <source>Frequency refinement</source>
        <translation>Частота уточнения</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1311"/>
        <location filename="../ui/ConfigForm.ui" line="1314"/>
        <location filename="../ui/ConfigForm.ui" line="1396"/>
        <location filename="../ui/ConfigForm.ui" line="1399"/>
        <source>Use a refinement method in frequency domain: compute the mean of the quasi-harmonic related spectral peaks (the option allows to chose the number of harmonics to use).</source>
        <translation>Использовать метод уточнения в области частот:
вычислить среднее значение квазигармонических связанных спектральных пиков
(опция позволяет выбрать количество гармоник для использования).</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1324"/>
        <location filename="../ui/ConfigForm.ui" line="1327"/>
        <location filename="../ui/ConfigForm.ui" line="1342"/>
        <location filename="../ui/ConfigForm.ui" line="1345"/>
        <location filename="../ui/ConfigForm.ui" line="1373"/>
        <location filename="../ui/ConfigForm.ui" line="1376"/>
        <source>Use a refinement method in time domain: compute the mean of various period lengths (the option allows to chose the number of periods to use).</source>
        <translation>Использовать метод уточнения во временной области:
вычислить среднее значение различных длин периодов
(опция позволяет выбрать количество периодов для использования).</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1427"/>
        <location filename="../ui/ConfigForm.ui" line="1432"/>
        <source>Frequency domain fundamental refinement:
mean of the fundamental relative frequencies of the harmonics.
Choose the number of harmonics to use.</source>
        <translation>Основное уточнение частотной области:
среднее значение из основных относительных частот гармоник.
Выберите количество гармоник.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1317"/>
        <source>Maximum number of harmonics</source>
        <translation>Максимальное число гармоник</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1330"/>
        <source>Maximum number of periods</source>
        <translation>Максимальное число периодов</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1455"/>
        <location filename="../ui/ConfigForm.ui" line="1458"/>
        <source>Quantizer settings</source>
        <translation>Настройки квантования</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1461"/>
        <source>Quantizer</source>
        <translation>Квантование</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1480"/>
        <source>Latency</source>
        <translation>Задержка</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1544"/>
        <source>Restore &amp;factory settings</source>
        <translation>&amp;Восстановить настройки по умолчанию</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1573"/>
        <source>&amp;OK</source>
        <translation>&amp;ОК</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1592"/>
        <source>&amp;Cancel</source>
        <translation>Отме&amp;на</translation>
    </message>
</context>
<context>
    <name>CustomInstrumentTunerForm</name>
    <message>
        <location filename="../src/CustomInstrumentTunerForm.cpp" line="1054"/>
        <location filename="../src/CustomInstrumentTunerForm.cpp" line="1067"/>
        <source>Restore Factory Settings</source>
        <translation>Восстановить настройки по умолчанию</translation>
    </message>
    <message>
        <location filename="../src/CustomInstrumentTunerForm.cpp" line="1054"/>
        <source>This operation is NOT reversible.
Are you sure you want to lose all your current settings ?</source>
        <translation>Это НЕОБРАТИМАЯ операция.
Вы действительно хотите потерять все ваши настройки?</translation>
    </message>
    <message>
        <location filename="../src/CustomInstrumentTunerForm.cpp" line="1067"/>
        <source>You can now restart FMIT to get back factory settings</source>
        <translation>Теперь вы можете перезапустить FMIT, чтобы вернуться к настройкам по умолчанию</translation>
    </message>
    <message>
        <location filename="../src/CustomInstrumentTunerForm.cpp" line="1174"/>
        <source>Transposition in number of semitones relative to %1.
Useful to convert note names to a corresponding transposing instrument (e.g. %2 for saxophone, %3 for trumpet).</source>
        <translation>Транспонирование на количество полутонов относительно %1.
Полезно для преобразования имен нот в соответствующий транспонирующий инструмент (например, %2 для саксофона, %3 для трубы).</translation>
    </message>
    <message>
        <location filename="../src/CustomInstrumentTunerForm.cpp" line="1187"/>
        <source>The base tunning frequency (the %1 frequency)</source>
        <translation>Базовая частота настройки (частота %1)</translation>
    </message>
    <message>
        <location filename="../src/CustomInstrumentTunerForm.cpp" line="1194"/>
        <source>Allows to add an offset to the reference %1</source>
        <translation>Позволяет добавить смещение к %1</translation>
    </message>
    <message>
        <location filename="../src/CustomInstrumentTunerForm.cpp" line="1198"/>
        <source>Range of possible notes from the lowest to the highest around the %1 reference note.
Smaller the range, smaller the CPU usage.</source>
        <translation>Диапазон возможных нот от самого низкого до самого высокого уровня вокруг %1.
Чем меньше диапазон, тем меньше нагрузка на процессор.</translation>
    </message>
    <message>
        <location filename="../src/CustomInstrumentTunerForm.cpp" line="1203"/>
        <source>Lowest semitone from the %1 reference note.
It can useful to put it higher than -35 to avoid disturbance from the sector alimentation (~50hz).</source>
        <translation>Самый низкий полутон от %1.
Может быть полезно поставить его выше -35, чтобы избежать наводок от электросети (~50 Гц).</translation>
    </message>
    <message>
        <location filename="../src/CustomInstrumentTunerForm.cpp" line="1210"/>
        <source>Highest semitone from the %1 reference note.</source>
        <translation>Самый высокий полутон от %1.</translation>
    </message>
</context>
<context>
    <name>DialView</name>
    <message>
        <location filename="../src/modules/DialView.cpp" line="15"/>
        <source>Dial</source>
        <translation>Шкала</translation>
    </message>
    <message>
        <location filename="../src/modules/DialView.cpp" line="22"/>
        <source>Show tolerance</source>
        <translation>Показать погрешность</translation>
    </message>
    <message>
        <location filename="../src/modules/DialView.cpp" line="28"/>
        <source>Show trace</source>
        <translation>Показать след</translation>
    </message>
    <message>
        <location filename="../src/modules/DialView.cpp" line="34"/>
        <source>Use cents</source>
        <translation>Использовать центы</translation>
    </message>
    <message>
        <location filename="../src/modules/DialView.cpp" line="42"/>
        <source>Scale range</source>
        <translation>Диапазон строя</translation>
    </message>
    <message>
        <location filename="../src/modules/DialView.cpp" line="50"/>
        <source>Scale range (in cents)</source>
        <translation>Диапазон строя (в центах)</translation>
    </message>
</context>
<context>
    <name>GLErrorHistory</name>
    <message>
        <location filename="../src/modules/GLErrorHistory.cpp" line="75"/>
        <source>Error history</source>
        <translation>История ошибок</translation>
    </message>
    <message>
        <location filename="../src/modules/GLErrorHistory.cpp" line="82"/>
        <source>Keep previous notes</source>
        <translation>Сохранять предыдущие ноты</translation>
    </message>
    <message>
        <location filename="../src/modules/GLErrorHistory.cpp" line="88"/>
        <source>Use cents</source>
        <translation>Использовать центы</translation>
    </message>
    <message>
        <location filename="../src/modules/GLErrorHistory.cpp" line="96"/>
        <source>Scale range</source>
        <translation>Диапазон строя</translation>
    </message>
    <message>
        <location filename="../src/modules/GLErrorHistory.cpp" line="104"/>
        <source>Scale range (in cents)</source>
        <translation>Диапазон строя (в центах)</translation>
    </message>
    <message>
        <location filename="../src/modules/GLErrorHistory.cpp" line="229"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
</context>
<context>
    <name>GLFT</name>
    <message>
        <location filename="../src/modules/GLFT.cpp" line="52"/>
        <source>dB scale</source>
        <translation>Шкала дБ</translation>
    </message>
    <message>
        <location filename="../src/modules/GLFT.cpp" line="61"/>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <location filename="../src/modules/GLFT.cpp" line="71"/>
        <source>window length</source>
        <translation>длина окна</translation>
    </message>
    <message>
        <location filename="../src/modules/GLFT.cpp" line="83"/>
        <source>- Press left mouse button to move the view</source>
        <translation>- Нажмите левую кнопку мыши чтобы переместить отображение</translation>
    </message>
    <message>
        <location filename="../src/modules/GLFT.cpp" line="86"/>
        <source>- Press SHIFT key and left mouse button to zoom in and out</source>
        <translation>- Нажмите Shift и левую кнопку мыши для изменения масштаба</translation>
    </message>
    <message>
        <location filename="../src/modules/GLFT.cpp" line="89"/>
        <source>- Double-click to reset the view</source>
        <translation>- Двойное нажатие сбрасывает отображение</translation>
    </message>
    <message>
        <location filename="../src/modules/GLFT.cpp" line="177"/>
        <source>Frequency %1 [Hz]</source>
        <translation>Частота %1 [Гц]</translation>
    </message>
    <message>
        <location filename="../src/modules/GLFT.cpp" line="39"/>
        <location filename="../src/modules/GLFT.cpp" line="253"/>
        <source>Fourier Transform</source>
        <translation>Преобразование Фурье</translation>
    </message>
</context>
<context>
    <name>GLFreqStruct</name>
    <message>
        <location filename="../src/modules/GLFreqStruct.cpp" line="44"/>
        <location filename="../src/modules/GLFreqStruct.cpp" line="53"/>
        <source>Number of harmonics</source>
        <translation>Число гармоник</translation>
    </message>
    <message>
        <location filename="../src/modules/GLFreqStruct.cpp" line="182"/>
        <source>Harmonics&apos; amplitude</source>
        <translation>Амплитуда гармоник</translation>
    </message>
    <message>
        <location filename="../src/modules/GLFreqStruct.cpp" line="33"/>
        <source>Harmonics</source>
        <translation>Гармоники</translation>
    </message>
</context>
<context>
    <name>GLGraph</name>
    <message>
        <location filename="../src/modules/GLGraph.cpp" line="43"/>
        <source>Show Wave Form</source>
        <translation>Показать форму волны</translation>
    </message>
    <message>
        <location filename="../src/modules/GLGraph.cpp" line="49"/>
        <source>Auto scale</source>
        <translation>Автоматическое масштабирование</translation>
    </message>
    <message>
        <location filename="../src/modules/GLGraph.cpp" line="57"/>
        <location filename="../src/modules/GLGraph.cpp" line="64"/>
        <source>Scale factor</source>
        <translation>Масштаб</translation>
    </message>
    <message>
        <location filename="../src/modules/GLGraph.cpp" line="78"/>
        <location filename="../src/modules/GLGraph.cpp" line="85"/>
        <source>Duration</source>
        <translation>Продолжительность</translation>
    </message>
    <message>
        <location filename="../src/modules/GLGraph.cpp" line="99"/>
        <location filename="../src/modules/GLGraph.cpp" line="106"/>
        <source>Max height</source>
        <translation>Максимальная высота</translation>
    </message>
    <message>
        <location filename="../src/modules/GLGraph.cpp" line="34"/>
        <location filename="../src/modules/GLGraph.cpp" line="267"/>
        <source>Captured Sound</source>
        <translation>Захваченный звук</translation>
    </message>
</context>
<context>
    <name>GLSample</name>
    <message>
        <location filename="../src/modules/GLSample.cpp" line="34"/>
        <source>Waveform</source>
        <translation>Форма волны</translation>
    </message>
    <message>
        <location filename="../src/modules/GLSample.cpp" line="43"/>
        <source>Show fading</source>
        <translation>Показать спад</translation>
    </message>
    <message>
        <location filename="../src/modules/GLSample.cpp" line="50"/>
        <location filename="../src/modules/GLSample.cpp" line="58"/>
        <source>Number of fading</source>
        <translation>Число спада</translation>
    </message>
    <message>
        <location filename="../src/modules/GLSample.cpp" line="127"/>
        <source>Waveform&apos;s period</source>
        <translation>Период волны</translation>
    </message>
</context>
<context>
    <name>GLStatistics</name>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="200"/>
        <source>Reset statistics</source>
        <translation>Сбросить статистику</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="205"/>
        <source>Keep notes when hidden</source>
        <translation type="unfinished">Сохранить ноты в свернутом состоянии</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="213"/>
        <source>Keep n values</source>
        <translation>Хранить n значений</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="222"/>
        <source>Keep this number of values in the computation of the statistics</source>
        <translation>Хранить этот ряд значений при расчете статистических данных</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="236"/>
        <source>Show standard deviation</source>
        <translation>Показать стандартное отклонение</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="242"/>
        <source>Scale auto</source>
        <translation>Автоматическое масштабирование</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="251"/>
        <source>Scale min</source>
        <translation>Минимальное значение шкалы</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="260"/>
        <source>Scale min value (in semi-tones)</source>
        <translation>Минимальное значение шкалы (в полутонах)</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="278"/>
        <source>Scale max</source>
        <translation>Максимальное значение шкалы</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="287"/>
        <source>Scale max value (in semi-tones)</source>
        <translation>Максимальное значение шкалы (в полутонах)</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="303"/>
        <source>Show tolerance</source>
        <translation>Показать погрешность</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="309"/>
        <source>Use cents</source>
        <translation>Использовать центы</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="317"/>
        <source>Scale range</source>
        <translation>Диапазон строя</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="325"/>
        <source>Scale range (in cents)</source>
        <translation>Диапазон строя (в центах)</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="192"/>
        <location filename="../src/modules/GLStatistics.cpp" line="437"/>
        <source>Statistics</source>
        <translation>Статистика</translation>
    </message>
</context>
<context>
    <name>GLVolumeHistory</name>
    <message>
        <location filename="../src/modules/GLVolumeHistory.cpp" line="49"/>
        <source>Volume history</source>
        <translation>История громкости</translation>
    </message>
    <message>
        <location filename="../src/modules/GLVolumeHistory.cpp" line="59"/>
        <source>Keep previous notes</source>
        <translation>Сохранять предыдущие ноты</translation>
    </message>
    <message>
        <location filename="../src/modules/GLVolumeHistory.cpp" line="128"/>
        <source>Volume</source>
        <translation>Громкость</translation>
    </message>
</context>
<context>
    <name>InstrumentTunerForm</name>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="14"/>
        <source>Free Music Instrument Tuner</source>
        <translation>Свободный тюнер музыкальных инструментов</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="55"/>
        <source>K
e
e
p</source>
        <translation>С
о
х
р
а
н
и
т
ь</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="61"/>
        <source>K</source>
        <translation>С</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="168"/>
        <source>Note Stability</source>
        <translation>Стабильность ноты</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="192"/>
        <source>Tuning Frequency</source>
        <translation>Частота настройки</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="227"/>
        <source> Hz</source>
        <translation> Гц</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="256"/>
        <source>Offset</source>
        <translation>Смещение</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="284"/>
        <source> cents</source>
        <translation> центов</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="348"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="351"/>
        <source>The recognized note</source>
        <translation>Распознанная нота</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="49"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="52"/>
        <source>Keep the data in the error and volume views (shortcut &quot;k&quot;).</source>
        <translation>Сохранять данные в режимах отображения ошибок и громкости (горячая клавиша &quot;k&quot;).</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="111"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="116"/>
        <source>Volume in dB.
Computed in the frequency domain, from the maximum bin.
The maximum is reached when the signal energy is maximal NOT when the sound is saturated in the time domain.</source>
        <translation type="unfinished">Громкость в дБ.
Вычисленная в частотной области от максимального bin.
Максимум достигается, когда сила сигнала максимальна, а не когда звук сатурирован в области времени.</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="151"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="158"/>
        <source>According to the following colors:
red       : the capture system is not working.
grey     : the capture system is OK, but there is not enough sound.
orange : the analysis conditions are bad (like saturation)
green   : a note is beeing analyzed and analysis conditions are OK.</source>
        <translation type="unfinished">В соответствии со следующими цветами:
красный       : захват звука отключен.
серый           : захват звука производится, но сила сигнала недостаточна.
оранжевый : плохие условия для анализа (напр. сатурация)
зеленый       : нота определяется, условия анализа хорошие.</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="221"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="224"/>
        <source>The base tunning frequency (the A4 frequency)</source>
        <translation>Базовая частота настройки (частота ноты A4)</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="250"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="253"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="278"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="281"/>
        <source>Offset in cents from the base tuning frequency</source>
        <translation>Смещение от базовой частоты настройки в центах</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="322"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="325"/>
        <source>The frequency of the current note in Hertz.</source>
        <translation>Частота данной ноты в герцах.</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="376"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="379"/>
        <source>The target frequency of the current note in Hertz.</source>
        <translation>Целевая частота данной ноты в герцах.</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="408"/>
        <source>Views</source>
        <translation>Режимы отображения</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="422"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="444"/>
        <source>Pause</source>
        <translation>Пауза</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="447"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="450"/>
        <source>Pause: the capture, the sound analysis and all views.</source>
        <translation>Пауза: захват, анализ и все режимы отображения.</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="480"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="483"/>
        <source>Save configuration panel settings, views settings and the window size.</source>
        <translation>Сохранить конфигурацию, настройки отображения и размер окна.</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="501"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="504"/>
        <source>Invoke the about box.</source>
        <translation>Вызвать окно &quot;О программе&quot;.</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="453"/>
        <source>Space</source>
        <translation>Пробел</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="465"/>
        <source>Configure</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="477"/>
        <source>Save settings</source>
        <translation>Сохранить настройки</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="486"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="498"/>
        <source>About</source>
        <translation>О программе</translation>
    </message>
</context>
<context>
    <name>MicrotonalView</name>
    <message>
        <location filename="../src/modules/MicrotonalView.cpp" line="182"/>
        <source>Unkown filename: &apos;</source>
        <translation>Неизвестное имя файла: &apos;</translation>
    </message>
    <message>
        <location filename="../src/modules/MicrotonalView.cpp" line="286"/>
        <source>Microtonal</source>
        <translation>Микротональный</translation>
    </message>
    <message>
        <location filename="../src/modules/MicrotonalView.cpp" line="287"/>
        <source>Used scale</source>
        <translation>Используемый строй</translation>
    </message>
    <message>
        <location filename="../src/modules/MicrotonalView.cpp" line="304"/>
        <location filename="../src/modules/MicrotonalView.cpp" line="311"/>
        <source>Root&apos;s octave</source>
        <translation>Октава тоники</translation>
    </message>
    <message>
        <location filename="../src/modules/MicrotonalView.cpp" line="325"/>
        <source>Keep root to left side</source>
        <translation>Держать тонику по левому краю</translation>
    </message>
    <message>
        <location filename="../src/modules/MicrotonalView.cpp" line="330"/>
        <source>Load Scala file ...</source>
        <translation>Открыть файл Scala ...</translation>
    </message>
    <message>
        <location filename="../src/modules/MicrotonalView.cpp" line="803"/>
        <location filename="../src/modules/MicrotonalView.cpp" line="810"/>
        <location filename="../src/modules/MicrotonalView.cpp" line="842"/>
        <location filename="../src/modules/MicrotonalView.cpp" line="846"/>
        <source>Open scale file</source>
        <translation>Открытый файл строя</translation>
    </message>
    <message>
        <location filename="../src/modules/MicrotonalView.cpp" line="842"/>
        <source>Scale name already exist</source>
        <translation>Название строя уже существует</translation>
    </message>
    <message>
        <location filename="../src/modules/MicrotonalView.cpp" line="846"/>
        <source>Invalid file content !</source>
        <translation>Ошибочное содержимое файла!</translation>
    </message>
    <message>
        <location filename="../src/modules/MicrotonalView.cpp" line="927"/>
        <source>&lt;b&gt;name:&lt;/b&gt; </source>
        <translation>&lt;b&gt;название:&lt;/b&gt; </translation>
    </message>
    <message>
        <location filename="../src/modules/MicrotonalView.cpp" line="928"/>
        <source>&lt;b&gt;number of ratio:&lt;/b&gt; </source>
        <translation>&lt;b&gt;соотношение:&lt;/b&gt; </translation>
    </message>
    <message>
        <location filename="../src/modules/MicrotonalView.cpp" line="934"/>
        <source>Invalid Scala file: </source>
        <translation>Ошибочный файл Scala: </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/CaptureThread.cpp" line="368"/>
        <source>default</source>
        <translation>по умолчанию</translation>
    </message>
    <message>
        <location filename="../src/modules/View.cpp" line="86"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
</context>
</TS>
